import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.Comparator;

class Fish {
  public long x;
  public long y;
}
class cmpFish implements Comparator<Fish> {
  cmpFish() {}
  public int compare(Fish f, Fish f1) {
    if (f.x == f1.x) {
      return (int)(f.y - f1.y);
    }
    return (int)(f.x - f1.x);
  }
}

public class PenguinFishCatching {
  
  // Before submitting, make sure the main method hasn't been changed!
  public static void main(String[] args) throws IOException {
    BufferedReader br = new BufferedReader(new FileReader("PenguinFishCatchingIN.txt"));

    while (br.ready()) {
      String[] data = br.readLine().split(" ");
      long startingPosition = Long.parseLong(data[0]);
      long waddlingSpeed = Long.parseLong(data[1]);

      int nFish = Integer.parseInt(br.readLine());
      long[] landingTimes = new long[nFish];
      long[] landingPositions = new long[nFish];

      data = br.readLine().split(" ");
      for (int i = 0; i < nFish; i++) {
        landingTimes[i] = Long.parseLong(data[i]);
      }
      data = br.readLine().split(" ");
      for (int i = 0; i < nFish; i++) {
        landingPositions[i] = Long.parseLong(data[i]);
      }
      System.out.println(maxFishCaught(startingPosition, waddlingSpeed, landingTimes, landingPositions));
    }
    br.close();
  }

  // Fill out the body of this method
  public static long maxFishCaught(long startingPosition, long waddlingSpeed, long[] landingTimes, long[] landingPositions) {
    int nFish = landingTimes.length;
    Fish[] fish = new Fish[nFish];
    // Consider each fish on the plane, with the landing position as x-coordinate and (landing time)*(speed) as y-coordinate
    // Then, if we catch a given fish F, the set of possible "next fish to catch" is a V shaped region above F, bounded by 
    // lines of gradient 1 and -1. Now, "tilt" your head 45 degrees to the left. On this new rotated coordinate system, from some
    // given fish F, we can go to any "next fish" with both x and y coordinate greater than F, and we want to find some longest
    // sequence of fish to catch. (Note: from now on, we use the rotated coordinate system rather than the original system)
    for (int i = 0; i < nFish; i++) {
      fish[i] = new Fish();
      fish[i].x = (waddlingSpeed * landingTimes[i]) + landingPositions[i];
      fish[i].y = (waddlingSpeed * landingTimes[i]) - landingPositions[i];
    }

    // Thus, to solve this, we use dynamic programming. First, we sort the fishes by x-coordinate. Then, as we iterate through the
    // fish, we store an array bestPos[], where bestPos[i] represents the smallest possible ending y-coordinate for a sequence of fish 
    // of length i. Note that bestPos[i] will be increasing, since a longer sequence has to end on a larger y-coordinate. Thus, for every
    // new fish, we can binary search to find what length of sequence we should append the new fish to, then update bestPos[] accordingly.
    // Once we loop through all the fishes, the longest sequence we managed to generate will be the solution we want.

    // Note: Astute coders may notice that this is actually an instance of the longest increasing subsequence problem. You can read more about it
    // over here: http://en.wikipedia.org/wiki/Longest_increasing_subsequence.
    Arrays.sort(fish, new cmpFish());
    long[] bestPos = new long[nFish+1];
    int maxLen = 0;
    for (int i = 0; i <= nFish; i++) bestPos[i] = 0;
    bestPos[0] = -startingPosition;
    for (int i = 0; i < nFish; i++) {
      if (fish[i].x < startingPosition || fish[i].y < -startingPosition) continue;
      int l = -1;
      int r = maxLen + 1;
      while (l < r - 1) {
        int m = (l+r)/2;
        if (bestPos[m] > fish[i].y) {
          r = m;
        } else {
          l = m;
        }
      }
      bestPos[r] = fish[i].y;
      if (r > maxLen) {
        maxLen = r;
      }
    }

    return (long) maxLen;
  }
}
