import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.ArrayDeque;

class Robot {
  long xPosition;
  long yPosition;
  long detectionRange;
  Robot(){}
}

class Vertex {
  HashMap<Integer, Integer> edges;
  Vertex() { edges = new HashMap<Integer,Integer>(); }
}

public class PenguinsVersusRobots {
  // Before submitting, make sure the main method hasn't been changed!
  public static void main(String[] args) throws IOException {
    BufferedReader br = new BufferedReader(new FileReader("PenguinsVersusRobotsIN.txt"));

    while (br.ready()) {
      String[] data = br.readLine().split(" ");
      long valleyWidth = Long.parseLong(data[0]);
      long valleyHeight = Long.parseLong(data[1]);
      int nRobots = Integer.parseInt(br.readLine()); 
      Robot[] robots = new Robot[nRobots];
      for (int i = 0; i < nRobots; i++) {
        robots[i] = new Robot();
        data = br.readLine().split(" ");
        robots[i].xPosition = Long.parseLong(data[0]);
        robots[i].yPosition = Long.parseLong(data[1]);
        robots[i].detectionRange = Long.parseLong(data[2]);
      }

      System.out.println(minRobotsKilled(valleyWidth, valleyHeight, robots));
    }
    br.close();
  }

  private static long dist_sq(long x1, long y1, long x2, long y2) {
    return (x2 - x1)*(x2 - x1) + (y2 - y1)*(y2 - y1);
  }

  // Fill out the body of this method
  public static long minRobotsKilled(long valleyWidth, long valleyHeight, Robot[] robots) {
    // We use the max-flow min-cut theorem to solve this:
    // Construct a flow graph as follows: the n-th robot has two vertices labeled 2n and 2n+1.
    // The source vertex will be labeled 2N and the sink vertex 2N+1. For the n-th robot, vertex 2n 
    // will be the "in" vertex and 2n+1 will be the "out" vertex. Now, add an edge with capacity 1 
    // from 2n to 2n+1. Cutting this edge represents destroying this robot. Also, between any two robots
    // which have intersecting detection ranges, add an edge with infinite capacity from the "out" vertex 
    // of the first robot to the "in" vertex of the second, and vice versa. Then, add edges from the source
    // to "in" vertices of robots with ranges touching the top wall, and from "out" vertices of robots with
    // ranges touching the bottom wall to the sink.

    // This works because if there is a flow from source to sink, then that represents an unbroken sequence of
    // robots from top wall to bottom wall blocking the way. Thus, the min-cut of the graph represents the minimum
    // number of robots removed to prevent this from occuring.

    Vertex[] vertices = new Vertex[2 + robots.length * 2];
    int source = 2 * robots.length;
    int sink = 2 * robots.length + 1;
    for (int i = 0; i < vertices.length; i++) vertices[i] = new Vertex();
    int INF = robots.length + 1; // "effectively infinite"
    for (int i = 0; i < robots.length; i++) {
      vertices[2 * i].edges.put(2 * i + 1, 1);
      vertices[2 * i + 1].edges.put(2 * i, 0);
      if (robots[i].yPosition >= valleyHeight - robots[i].detectionRange) {
        vertices[source].edges.put(2 * i, INF);
        vertices[2 * i].edges.put(source, 0);
      }
      if (robots[i].yPosition <= robots[i].detectionRange) {
        vertices[2 * i + 1].edges.put(sink, INF);
        vertices[sink].edges.put(2 * i + 1, 0);
      }
      for (int j = 0; j < robots.length; j++) {
        if (i == j) continue;
        if (dist_sq(robots[i].xPosition, robots[i].yPosition, robots[j].xPosition, robots[j].yPosition) <= 
            (robots[i].detectionRange + robots[j].detectionRange)*(robots[i].detectionRange + robots[j].detectionRange)) {
          vertices[2 * i + 1].edges.put(2 * j, INF);
          vertices[2 * j].edges.put(2 * i + 1, 0);
        }
      }
    }
    // Now, use the Ford-Fulkerson algorithm to find max-flow
    boolean hasFlow = false;
    long ret = 0;
    ArrayDeque<Integer> q = new ArrayDeque<Integer>(vertices.length + 1);
    int[] prev = new int[vertices.length];
    do {
      q.clear();
      hasFlow = false;
      for (int i = 0; i < prev.length; i++) prev[i] = -1;
      q.addLast(source);
      while (!q.isEmpty()) {
        int cur = q.removeFirst();
        if (cur == sink) {
          hasFlow = true;
          break;
        }
        for (HashMap.Entry<Integer, Integer> entry : vertices[cur].edges.entrySet()) {
          int nxt = entry.getKey();
          int cap = entry.getValue();
          if (prev[nxt] != -1 || cap <= 0) continue;
          prev[nxt] = cur;
          q.addLast(nxt);
        }
      }
      if (hasFlow) {
        ret++;
        int cur = sink;
        while (cur != source) {
          vertices[prev[cur]].edges.put(cur, vertices[prev[cur]].edges.get(cur) - 1);
          vertices[cur].edges.put(prev[cur], vertices[cur].edges.get(prev[cur]) + 1);
          cur = prev[cur];
        }
      }
    } while (hasFlow);
    return ret;
  }
}
