import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;


public class Procrastination {

	public static void main(String[] args) throws IOException {
		BufferedReader reader = new BufferedReader(
				new FileReader("ProcrastinationIN.txt"));

		while(reader.ready()){

			int[][] board = new int[4][4];

			for(int row = 0; row < 4; row++){
				String ln = reader.readLine();
				String[] nums = ln.split(" ");

				for(int col = 0; col < 4; col++){
					board[row][col] = Integer.parseInt(nums[col].trim());
				}
			}

			System.out.println(procrastinate(board));

		}

		reader.close();
	}

	public static boolean procrastinate(int[][] board) {
		return procrastinate(board, 7);
	}

	private static boolean procrastinate(int[][] board, int i) {
		if(has2048(board)){
			return true;
		}
		if(i == 0){
			return false;
		}
		
		if(procrastinate(moveRight(board), i - 1) == true){
			return true;
		}
		if(procrastinate(moveDown(board), i - 1) == true){
			return true;
		}
		if(procrastinate(moveLeft(board), i - 1) == true){
			return true;
		}
		if(procrastinate(moveUp(board), i - 1) == true){
			return true;
		}
		
		return false;
	}

	private static boolean has2048(int[][] board){
		for(int[] row : board){
			for(int num : row){
				if(num == 2048){
					return true;
				}
			}
		}
		
		return false;
	}
	
	private static int[][] moveRight(int[][] board){
		int[][] copy = new int[4][4];
		for(int row = 0; row < 4; row++){ 
			for(int col = 0; col < 4; col++){
				copy[row][col] = board[row][col];
			}
		}

		for(int row = 0; row < 4; row++){ 
			for(int col = 3; col >= 0; col--){
				int old = copy[row][col];
				shift(copy, 1, row, col);
				if(copy[row][col] != 2*old){
					shift(copy, 1, row, col);
				}
			}
		}

		return copy;
	}
	
	private static int[][] moveDown(int[][] board){
		int[][] copy = new int[4][4];
		for(int row = 0; row < 4; row++){ 
			for(int col = 0; col < 4; col++){
				copy[row][col] = board[row][col];
			}
		}

		for(int col = 0; col < 4; col++){ 
			for(int row = 3; row >= 0; row--){
				int old = copy[row][col];
				shift(copy, 2, row, col);
				if(copy[row][col] != 2*old){
					shift(copy, 2, row, col);
				}
			}
		}

		return copy;
	}
	
	private static int[][] moveLeft(int[][] board){
		int[][] copy = new int[4][4];
		for(int row = 0; row < 4; row++){ 
			for(int col = 0; col < 4; col++){
				copy[row][col] = board[row][col];
			}
		}

		for(int row = 0; row < 4; row++){ 
			for(int col = 0; col < 4; col++){
				int old = copy[row][col];
				shift(copy, 3, row, col);
				if(copy[row][col] != 2*old){
					shift(copy, 3, row, col);
				}
			}
		}

		return copy;
	}
	
	private static int[][] moveUp(int[][] board){
		int[][] copy = new int[4][4];
		for(int row = 0; row < 4; row++){ 
			for(int col = 0; col < 4; col++){
				copy[row][col] = board[row][col];
			}
		}

		for(int col = 0; col < 4; col++){ 
			for(int row = 0; row < 4; row++){
				int old = copy[row][col];
				shift(copy, 4, row, col);
				if(copy[row][col] != 2*old){
					shift(copy, 4, row, col);
				}
			}
		}

		return copy;
	}

	private static void shift(int[][] copy, int dir, int row, int col) {
		if(dir == 1){
			int i = col - 1;

			if(i >= 0 && i < 4){
				while(i >= 0 && copy[row][i] == 0){
					i--;
				}
			}

			if(i >= 0 && i < 4){
				if(copy[row][i] == copy[row][col]){
					copy[row][col] *= 2;
					copy[row][i] = 0;
				}
				else if(copy[row][col] == 0){
					copy[row][col] = copy[row][i];
					copy[row][i] = 0;
				}
			}

		}

		if(dir == 2){
			int i = row - 1;

			if(i >= 0 && i < 4){
				while(i >= 0 && copy[i][col] == 0){
					i--;
				}
			}

			if(i >= 0 && i < 4){
				if(copy[i][col] == copy[row][col]){
					copy[row][col] *= 2;
					copy[i][col] = 0;
				}
				else if(copy[row][col] == 0){
					copy[row][col] = copy[i][col];
					copy[i][col] = 0;
				}
			}

		}

		if(dir == 3){
			int i = col + 1;

			if(i >= 0 && i < 4){
				while(i < 4 && copy[row][i] == 0){
					i++;
				}
			}

			if(i >= 0 && i < 4){
				if(copy[row][i] == copy[row][col]){
					copy[row][col] *= 2;
					copy[row][i] = 0;
				}
				else if(copy[row][col] == 0){
					copy[row][col] = copy[row][i];
					copy[row][i] = 0;
				}
			}

		}

		if(dir == 4){
			int i = row + 1;

			if(i >= 0 && i < 4){
				while(i < 4 && copy[i][col] == 0){
					i++;
				}
			}


			if(i >= 0 && i < 4){
				if(copy[i][col] == copy[row][col]){
					copy[row][col] *= 2;
					copy[i][col] = 0;
				}
				else if(copy[row][col] == 0){
					copy[row][col] = copy[i][col];
					copy[i][col] = 0;
				}
			}
		}

	}

}
